@@ -24,21 +24,20 @@
 #' print(Selectivity(portfolio_bacon[,1], portfolio_bacon[,2])) #expected -0.0141
 #'
 #' data(managers)
-#' print(Selectivity(managers['1996',1], managers['1996',8]))
-#' print(Selectivity(managers['1996',1:5], managers['1996',8]))
+#' print(Selectivity(managers['2002',1], managers['2002',8]))
+#' print(Selectivity(managers['2002',1:5], managers['2002',8]))
 #'
 #' @export
 
 Selectivity <-
 function (Ra, Rb, Rf = 0, ...)
 {
-	Period = Frequency(Ra)
-	CAPM.jensenAlpha(Ra,Rb,Rf,Period)
+	CAPM.jensenAlpha(Ra,Rb,Rf)
 }
 
 
 ###############################################################################
-# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
+# R (https://r-project.org/) Econometrics for Performance and Risk Analysis
 #
 # Copyright (c) 2004-2020 Peter Carl and Brian G. Peterson
 #
