@@ -36,14 +36,14 @@ sortDrawdowns <- function (runs) {
     
     # this version provided by H. Felix Wittman < hfwittmann <at> googlemail <dot> com >
     
-    index.sorted <- sort(runs$return, index=T)$ix # das kleinste zu erst
+    index.sorted <- sort(runs$return, index.return = TRUE)$ix # das kleinste zu erst
     runs.sorted <- lapply(runs, function(x) x <- x[index.sorted])
     
     return(runs.sorted)
 }
 
 ###############################################################################
-# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
+# R (https://r-project.org/) Econometrics for Performance and Risk Analysis
 #
 # Copyright (c) 2004-2020 Peter Carl and Brian G. Peterson
 #
