@@ -19,16 +19,17 @@
 #' \code{\link{InformationRatio}} \cr \code{\link{TreynorRatio}}
 ###keywords ts multivariate distribution models
 #' @examples
-#'
+#' \donttest{ # CRAN does not allow examples to load suggested packages in one of its tests
 #' data(managers)
 #' table.SFM(managers[,1:3], managers[,8], Rf = managers[,10])
 #'
 #' result = table.SFM(managers[,1:3], managers[,8], Rf = managers[,10])
+#' require(Hmisc)
 #' textplot(result, rmar = 0.8, cmar = 1.5,  max.cex=.9, 
 #'          halign = "center", valign = "top", row.valign="center", 
 #'          wrap.rownames=15, wrap.colnames=10, mar = c(0,0,3,0)+0.1)
 #' title(main="Single Factor Model Related Statistics")
-#'
+#'}
 #' @rdname table.CAPM
 #' @aliases
 #' table.CAPM
@@ -85,26 +86,42 @@ table.SFM <- table.CAPM <- function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
             merged.assets = merge(Ra.excess[,column.a,drop=FALSE], Rb.excess[,column.b,drop=FALSE])
             merged.assets = as.data.frame(na.omit(merged.assets)) # leaves the overlapping period
             # these should probably call CAPM.alpha and CAPM.beta for consistency (not performance)
-            model.lm = lm(merged.assets[,1] ~ merged.assets[,2])
-            alpha = coef(model.lm)[[1]]
-            beta = coef(model.lm)[[2]]
-            CAPMbull = CAPM.beta.bull(Ra[,column.a], Rb[,column.b],Rf) #inefficient, recalcs excess returns and intercept
-            CAPMbear = CAPM.beta.bear(Ra[,column.a], Rb[,column.b],Rf) #inefficient, recalcs excess returns and intercept
+            models = SFM.coefficients(merged.assets[,1] ,merged.assets[,2], method="Both", Model=T)
+            model.lm = models$LS$model
+            model.lmRobDetMM = models$robust$model
+            
+            alpha.lm = coef(model.lm)[[1]]
+            beta.lm = coef(model.lm)[[2]]
+            alpha.rob = coef(model.lmRobDetMM)[[1]]
+            beta.rob = coef(model.lmRobDetMM)[[2]]
+            
+            CAPMbull.lm = CAPM.beta.bull(Ra[,column.a], Rb[,column.b], Rf) #inefficient, recalcs excess returns and intercept
+            CAPMbear.lm = CAPM.beta.bear(Ra[,column.a], Rb[,column.b], Rf) #inefficient, recalcs excess returns and intercept
+            
+            CAPMbull.rob = CAPM.beta.bull(Ra[,column.a], Rb[,column.b], Rf, method="Robust") #inefficient, recalcs excess returns and intercept
+            CAPMbear.rob = CAPM.beta.bear(Ra[,column.a], Rb[,column.b], Rf, method="Robust") #inefficient, recalcs excess returns and intercept
+            
             htest = cor.test(as.numeric(merged.assets[,1]), as.numeric(merged.assets[,2]))
             #active.premium = (Return.annualized(merged.assets[,1,drop=FALSE], scale = scale) - Return.annualized(merged.assets[,2,drop=FALSE], scale = scale))
-            active.premium = ActivePremium(Ra=Ra[,column.a],Rb=Rb[,column.b], scale = scale)
+            active.premium = ActivePremium(Ra=Ra[,column.a], Rb=Rb[,column.b], scale = scale)
             #tracking.error = sqrt(sum(merged.assets[,1] - merged.assets[,2])^2/(length(merged.assets[,1])-1)) * sqrt(scale)
-            tracking.error = TrackingError(Ra[,column.a], Rb[,column.b],scale=scale)
+            tracking.error = TrackingError(Ra[,column.a], Rb[,column.b], scale=scale)
             #treynor.ratio = Return.annualized(merged.assets[,1,drop=FALSE], scale = scale)/beta
             treynor.ratio = TreynorRatio(Ra=Ra[,column.a], Rb=Rb[,column.b], Rf = Rf, scale = scale)
 
             z = c(
-                    alpha,
-                    beta,
-                    CAPMbull,
-                    CAPMbear,
+                    alpha.lm,
+                    beta.lm,
+                    alpha.rob,
+                    beta.rob,
+                    CAPMbull.lm,
+                    CAPMbear.lm,
+                    CAPMbull.rob,
+                    CAPMbear.rob,
+                    
                     summary(model.lm)$r.squared,
-                    ((1+alpha)^scale - 1),
+                    summary(model.lmRobDetMM)$r.squared,
+                    ((1+alpha.lm)^scale - 1),
                     htest$estimate,
                     htest$p.value,
                     tracking.error,
@@ -116,9 +133,14 @@ table.SFM <- table.CAPM <- function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
             znames = c(
                     "Alpha",
                     "Beta",
+                    "Alpha Robust",
+                    "Beta Robust",
                     "Beta+",
                     "Beta-",
+                    "Beta+ Robust",
+                    "Beta- Robust",
                     "R-squared",
+                    "R-squared Robust",
                     "Annualized Alpha",
                     "Correlation",
                     "Correlation p-value",
@@ -145,7 +167,7 @@ table.SFM <- table.CAPM <- function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
 }
 
 ###############################################################################
-# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
+# R (https://r-project.org/) Econometrics for Performance and Risk Analysis
 #
 # Copyright (c) 2004-2020 Peter Carl and Brian G. Peterson
 #
